# Topsis Module
Implementation of MCDM using topsis in python

## How to use it?
Open terminal and type "aaryan" followed by input_dataset(in csv), weights(comma separated), impacts(comma separated) and resulting_dataset_name(in csv) as shown below

(aaryan Test.csv 1,1,1,1,1 +,+,+,+,+ out.csv)

"USAGE :aaryan <input_file_name>.csv <weights>(1,1,1,1) <impacts>(+,+,-,+) <output_file_name>.csv"

## License

Ⓒ 2023 Aaryan Jain

This repository is licensed under the MIT license.
See LICENSE for details